timeseria.utilities
===================

.. automodule:: timeseria.utilities

   
   
   

   
   
   .. rubric:: Functions

   .. autosummary::
   
      check_data_keys
      check_resolution
      check_timeseries
      compute_coverage
      compute_data_loss
      detect_encoding
      detect_sampling_interval
      get_periodicity
      get_periodicity_index
      is_almost_equal
      is_close
      is_list_of_integers
      is_numerical
      item_is_in_range
      mean_absolute_percentage_error
      sanitize_string
      set_from_t_and_to_t
      to_float
      unit_to_TimeUnit
   
   

   
   
   

   
   
   



